#NIJI

[![Build Status](https://travis-ci.org/ericls/niji.svg?branch=master)](https://travis-ci.org/ericls/niji) [![Documentation Status](https://readthedocs.org/projects/django-niji/badge/?version=latest)](http://django-niji.readthedocs.io/en/latest/?badge=latest)

Django-NIJI is a pluggable forum APP for Django projects.

#### Demo
> https://demo.nijiforum.com/

#### Docs
> http://django-niji.rtfd.io